=================
How to Contribute
=================

Contributor License Agreement
-----------------------------

.. index::
   single: license; agreement

In order to contribute to the Ironic UI project, you need to have
signed OpenStack's contributor's agreement.

.. seealso::

   * https://docs.openstack.org/infra/manual/developers.html
   * https://wiki.openstack.org/CLA

Project Hosting Details
-------------------------

Bug tracker
    https://storyboard.openstack.org/#!/project/952

Mailing list (prefix subjects with ``[ironic]`` for faster responses)
    http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss

Code Hosting
    https://opendev.org/openstack/ironic-ui

Code Review
    https://review.opendev.org/#/q/status:open+project:openstack/ironic-ui,n,z
